process.env.NODE_ENV = 'test';

componentBuilder = require '../../lib/componentBuilder.js'
gruntHelper = require '../../lib/gruntHelper.js'


describe 'componentBuilder', ->
	Given ->
		@subject = componentBuilder
		@sampleConf = {
			sources:
				components: 'tests/e2e/sources/components'
			output:
				css:
					components: 'out/css/components'
		}

	Then -> typeof @subject == 'object'
	Then -> typeof @subject.init == 'function'
	Then -> typeof @subject.getComponentConfig == 'function'

	beforeEach -> @subject.init(@sampleConf)

	describe 'init', ->
		Then -> expect(@subject.conf).toEqual(@sampleConf)

	describe 'getComponentConfig', ->

		describe 'component without a config.json', ->
			Given -> @result = @subject.getComponentConfig('base/button')
			Then -> expect(@result).toEqual({})

		describe 'component having a config.json', ->
			Given -> @result = @subject.getComponentConfig('atomic-lib/molecules/columns-50')
			Then -> expect(@result).toEqual({"layout": "ef/layouts/columns"})


	describe 'getComponentVariations', ->

		describe 'component without variations', ->
			Given -> @result = @subject.getComponentVariations('atomic-lib/atoms/image')
			Then -> @result == null

		describe 'component with variations', ->
			Given -> @result = @subject.getComponentVariations('base/button')
			Then -> expect(@result).toEqual(['button--primary'])


	describe 'findComponentDependencies', ->

		describe 'component with no dependency', ->
			Given -> @result = @subject.findComponentDependencies({id:'base/hr', name:'hr'})
			Then -> expect(@result).toEqual({})

		describe 'component with explicit dependencies', ->
			Given -> @result = @subject.findComponentDependencies({id:'atomic-lib/organisms/header', name:'header'})
			Then -> expect(@result).toEqual({explicit:['base/button','atomic-lib/atoms/container']})

		describe 'component with variations', ->
			Given -> @result = @subject.findComponentDependencies({id:'base/button', name:'button'})
			Then -> expect(@result).toEqual({variations:['button--primary']})

		describe 'component with layout', ->
			Given -> @result = @subject.findComponentDependencies({id:'atomic-lib/molecules/columns-50', name:'columns-50'})
			Then -> expect(@result).toEqual({layout:'ef/layouts/columns'})